Ars Technica
Description: Serving the Technologist for more than a decade. IT news, reviews, and analysis.

# Top Post: It looks like the only thing about the new Terminator film that sucks is the name

## In-Depth Reports

1. # Sites certified as secure often more vulnerable to hacking, scientists find

   Security seals aren't worth the bits they're made of, let alone the fees.

   by Dan Goodin - Dec 4, 6:36 pm UTC

   26

2. # AT&T still throttles “unlimited data”—even when network not congested

   Half-megabit speeds force customers to abandon unlimited data.

   by Jon Brodkin - Dec 4, 6:16 pm UTC

   75

3. # New wave of credit card fraudsters opt for in-store pickup option

   Pilfered card data, Zip codes used by fraudsters to pick stores close to victims.

   by Sean Gallagher - Dec 4, 5:42 pm UTC

   37

4. # NASA’s first unmanned Orion launch scrubbed

   Stuck valve grounds the spacecraft's big Delta IV Heavy rocket until tomorrow.

   by Lee Hutchinson - Dec 4, 3:29 pm UTC

   51

5. # Another Aussie chain halts sales of GTA V, Take-Two responds [Updated]

   Retailer says move is "in line with the majority view of our customers."

   by Kyle Orland - Dec 4, 2:47 pm UTC

   237

6. # County sheriff finally gets the drone he wanted, ignores privacy concerns

   In 2015, Alameda County Sheriffs could be California's first cops to fly drones.

   by Cyrus Farivar - Dec 4, 12:50 am UTC

   69

7. # Video of police brutality can only do so much: NYPD chokehold cop not indicted

   Op-Ed: Even video evidence of a chokehold used by police won't protect certain citizens.

   by Megan Geuss - Dec 3, 11:15 pm UTC

   385

8. # Inside the “wiper” malware that brought Sony Pictures to its knees [Update]

   Analysis of code shows it used knowledge of Sony's Windows network to spread and wreak havoc.

   by Sean Gallagher - Dec 3, 11:00 pm UTC

   49

9. # Nature expands access to papers in its family of journals

   Read-only access will be available— but not universally.

   by Scott K. Johnson - Dec 3, 10:15 pm UTC

   28

10. # Comcast publicly doubts its own claim that merger won’t reduce competition

    Comcast blog post hit the Web before one incriminating sentence was removed.

    by Jon Brodkin - Dec 3, 9:30 pm UTC

    76

11. # This in-store robot can show you the hammer aisle, but not the bathroom

    Meet OSHbot, the new rolling service robot in a Silicon Valley hardware store.

    by Cyrus Farivar - Dec 3, 5:42 pm UTC

    63

12. # AT&T intervenes in city’s plan to offer fiber Internet to all residents [Updated]

    City in Kansas has to explain itself to state regulators and DSL provider AT&T.

    by Jon Brodkin - Dec 3, 5:17 pm UTC

    124

13. # Sony Pictures hack gets uglier; North Korea won’t deny responsibility [Updated]

    Employee salary, health data mixed in with other corporate data leaked.

    by Sean Gallagher - Dec 3, 12:10 am UTC

    134

14. # Data caps, limited competition a recipe for trouble in home Internet service

    Government report urges FCC intervention, but the agency is reluctant to act.

    by Jon Brodkin - Dec 2, 11:00 pm UTC

    161

15. # Critical networks in US, 15 other nations, completely owned, possibly by Iran

    Operation Cleaver gets near-complete control of airlines, gas producers, defense.

    by Dan Goodin - Dec 2, 10:30 pm UTC

    106

16. # Apple on trial: Were iTunes updates really an anti-consumer scheme?

    iTunes 7 added movies, album art—and stymied competing music stores.

    by Joe Mullin - Dec 2, 9:40 pm UTC

    105

17. # NTSB blames bad battery design—and bad management—in Boeing 787 fires

    Maker of lithium-ion batteries didn’t foresee spreading short circuit danger.

    by Sean Gallagher - Dec 2, 9:15 pm UTC

    75

18. # Netflix accused of creating fast lanes “at the expense of competitors”

    FCC commissioner revives claims made by Internet service providers.

    by Jon Brodkin - Dec 2, 8:15 pm UTC

    214

19. # Steam streams: Valve introduces gameplay-sharing broadcast feature

    "Steam Broadcasting" lets you share your gameplay with friends or the public.

    by Kyle Orland - Dec 2, 7:40 pm UTC

    76

20. # Was Apple’s iPod DRM illegal? Starting today, a jury decides

    Jurors, including one who said DRM "destroyed sharing," likely to hear from Jobs.

    by Joe Mullin - Dec 2, 2:30 pm UTC

    234

21. # Windows 7 up as Windows XP slides, Chrome growth stops in November

    Google's browser falters on both desktop and mobile.

    by Peter Bright - Dec 2, 3:40 am UTC

    193

22. # Obama wants to buy 50,000 body cams for police, monitor military gear handouts

    An extra $263 million in funding would be used toward training cops to use the tech.

    by Megan Geuss - Dec 2, 12:45 am UTC

    159

23. # Phishing scam that penetrated Wall Street just might work against you, too

    Advanced tactics raise the bar on spearphishing attacks, making them harder to spot.

    by Dan Goodin - Dec 1, 8:08 pm UTC

    92

24. # Save from your seat: The best Cyber Monday gaming deals

    Xbox One with three games from $329, and much more.

    by Kyle Orland - Dec 1, 5:44 pm UTC

    82

25. # Making social media research more reliable and reproducible

    Data sets from social sites can "misrepresent the real world," says study.

    by Cathleen O'Grady Dec 1, 5:00 pm UTC

    22

## Feature Story

# To address tech’s diversity woes, start with the vanishing Comp Sci classroom

The number of schools offering AP Computer Science has dropped 35% in recent years.

Latest Story

## On The Radar

1. ## nunc emere felicitate

   # Dealmaster says more monitors equals more happiness

   Two of Dell's biggest Ultrasharp screens are on sale—get 'em here!

   by Lee Hutchinson - Dec 4, 10:13 pm UTC

   3

2. ## long-term plan

   # DirectTV contract punishes HBO if streaming-only gets too popular, sources say

   It seems the TV provider has been planning for HBO's Web-only service for a while.

   by Megan Geuss - Dec 4, 9:10 pm UTC

   27

3. ## Your DNA can and will be used against you

   # Court strikes California law requiring DNA collection for felony arrestees

   State court goes against Supreme Court decision, cites California Constitution.

   by Cyrus Farivar - Dec 4, 8:50 pm UTC

   6

4. ## Dum dum dum da dum

   # It looks like the only thing about the new Terminator film that sucks is the name

   The Terminator Genisys trailer is a glorious (if appallingly spelled) blend of old and new.

   by Peter Bright - Dec 4, 8:30 pm UTC

   115

5. ## $300 million doesn't buy much these days

   # Microsoft, Barnes & Noble bring their weird Nook “partnership” to a formal end

   Microsoft investment put an end to a patent lawsuit, but not much else.

   by Peter Bright - Dec 4, 7:10 pm UTC

   15

6. ## feeling smashed

   # Smash Bros. creator doubts he’ll work on another sequel

   Sakurai: "We've arrived at a very difficult place" as far as advancing series.

   by Kyle Orland - Dec 4, 5:48 pm UTC

   25

7. ## Staff Blog

   # US natural gas production could peak in 2020

   Research project forecasts much less production than government estimates.

   by Scott K. Johnson - Dec 4, 2:00 pm UTC

   71

8. ## OK google, i wish i were big

   # Google to launch kid-friendly versions of Chrome, YouTube, others in 2015

   Children under the age of 12 are the target group, despite regulatory worries.

   by Andrew Cunningham - Dec 4, 12:30 am UTC

   43

9. ## Ars Editor’s Picks The web worth reading.

   1. My Great-Great-Aunt Discovered Francium. And It Killed Her. The New York Times
   2. A eulogy for RadioShack, the panicked and half-dead retail empire SB Nation
   3. Why the Surveillance State Lives On Politico Magazine

10. ## I am altering the deal

    # Sprint offers to cut your bill in half, but will also cut your data speed

    Also, Sprint isn't actually cutting your bill in half.

    by Jon Brodkin - Dec 3, 10:50 pm UTC

    44

11. ## Oppa Gangnam Style

    # Gangnam Style overflows INT_MAX, forces YouTube to go 64-bit

    Psy's hit song has been watched an awful lot of times.

    by Peter Bright - Dec 3, 10:32 pm UTC

    134

12. ## How do you turn this thing on?

    # Police officer fired for refusing to turn on body cam

    Albuquerque investigates the shooting of a 19-year-old that should be on tape.

    by Joe Mullin - Dec 3, 7:35 pm UTC

    243

13. ## The Week's Top Stories

    1. Learning the science behind silencers on the range with SilencerCo
    2. Cards Against Humanity calls bull**** on Black Friday, sells cow feces
    3. Goat MMO Simulator impressions: Massively moronic
    4. Firefly Space Systems charges full-speed toward low Earth orbit
    5. iWork ’14 review: Still waiting for that great leap forward [Updated]
    6. New Star Wars trailer definitely looks like Star Wars
    7. Data caps, limited competition a recipe for trouble in home Internet service
    8. Sony Pictures hack gets uglier; North Korea won’t deny responsibility [Updated]
    9. Music publishers finally pull the trigger, sue an ISP over piracy

14. ## Red Pandas are adorable

    # Firefox coming to iOS because that’s where the users are

    New iOS behavior makes this a little more palatable than before.

    by Peter Bright - Dec 3, 7:17 pm UTC

    68

15. ## Jarheads

    # Texas labs solve 20-year-old case of missing brains

    Mass murderer's brain may be among the recovered stash of nearly 100.

    by Sam Machkovech - Dec 3, 6:36 pm UTC

    38

16. ## AOL disk not included

    # Bandwidth-challenged developer? Google to ship Android SDKs on DVD

    You don't need great Internet access to develop on Google platforms.

    by Ron Amadeo - Dec 3, 5:47 pm UTC

    24

17. ## Tax this

    # UK to implement 25 percent “Google tax”

    Goal is to stop multinationals from dodging taxes on UK profits.

    by WIRED UK - Dec 3, 4:21 pm UTC

    123

18. ## URNOT(red)E

    # Limited-edition “original grey” PS4 pays homage to first PlayStation

    Sony celebrates the brand's 20th anniversary with a small, 12,300-system run.

    by Kyle Orland - Dec 3, 4:11 pm UTC

    70

19. ## even bluer teeth

    # New Bluetooth 4.2 spec brings IPv6, better privacy, and increased speed [Updated]

    Some, but not all, features will require new hardware.

    by Andrew Cunningham - Dec 3, 3:36 pm UTC

    26

20. ## This sounds bad

    # Android 5.0.1 released; fixes inadvertent factory reset bug

    Wi-Fi Nexus 9, Wi-Fi Nexus 7 (2013), and the Nexus 10 all get a bugfix release.

    by Ron Amadeo - Dec 3, 7:12 am UTC

    81

21. ## Boxed, Shelved

    # FBI seizes 20 boxes of documents on LAUSD iPad program

    $1.3-billion project crashes and burns as new superintendent shelves it.

    by Megan Geuss - Dec 3, 2:30 am UTC

    106

22. ## Internet silence

    # Verizon’s widely mocked tech news site is now completely dead [Updated]

    SugarString banned stories on spying and net neutrality. Now it writes nothing.

    by Jon Brodkin - Dec 2, 11:09 pm UTC

    73

23. ## read an e-book

    # New York Public Library will rent Wi-Fi hotspots to people who need it most

    Sprint Wi-Fi hotspots will be funded partly by a $1 million donation from Google.

    by Megan Geuss - Dec 2, 8:02 pm UTC

    25

24. ## How about a "block new accounts" option?

    # Twitter announces sweeping update to reporting, blocking tools

    But the update doesn't address how Twitter might better filter anonymous abuse.

    by Sam Machkovech - Dec 2, 7:31 pm UTC

    24

25. ## lighter than air

    # HP’s fanless 2.2-pound laptop includes Broadwell and a 2560×1440 screen

    12.5-inch EliteBook 1020 laptops are intriguing MacBook Air lookalikes.

    by Andrew Cunningham - Dec 2, 4:41 pm UTC

    100

26. ## unlike

    # LA man first to be sentenced under California’s “revenge porn” law

    Noe Iniguez will serve a year in jail and attend domestic violence counseling.

    by Megan Geuss - Dec 2, 3:46 pm UTC

    90

27. ## Now coming in "persistent" and "session" flavors

    # Thin Mints via thin devices: Girl Scout cookie sales finally go digital

    Participating scouts to sell cookies either via apps or personalized websites.

    by Sam Machkovech - Dec 1, 11:15 pm UTC

    60

28. ## Mucho dinero

    # Cricket to pay feds $2.1M after allegations it charged too much for wiretaps

    Case also settles accusations that AT&T subsidiary overbilled for pen registers.

    by Cyrus Farivar - Dec 1, 11:08 pm UTC

    33

29. ## People use the word "Cyber"? Really?

    # Cyber Monday Dealmaster has a 24” 16:10 Dell monitor for cheap

    Save $67 on the 1920×1200 display and get a $100 gift card.

    by Ars Staff - Dec 1, 4:15 pm UTC

    34

30. ## Loopholes über alles

    # German spy agency can monitor its own citizens via technicality

    Former BND lawyer: if citizen works abroad for foreign firm, it's fair game.

    by Cyrus Farivar - Nov 30, 4:13 pm UTC

    70

31. ## Code is poetry?

    # Holiday reading for a certain sort: If Hemingway Wrote JavaScript

    Important lesson: don’t hire Jack Kerouac to code a factorial function.

    by Sean Gallagher - Nov 29, 6:30 pm UTC

    52

32. ## Mood wrist ring

    # Sony lifts veil off 2015 e-ink watch line, other e-ink wearables

    Experiment began as a crowdfunded project under a different company name.

    by Sam Machkovech - Nov 29, 2:00 pm UTC

    63

33. ## Made in Germany

    # German government says “ja” to BlackBerry’s acquisition of Secusmart

    To get approval to buy Düsseldorf firm, BlackBerry had to sign "no-spy" deal.

    by Cyrus Farivar - Nov 29, 1:00 am UTC

    39

34. ## Ticket to ride

    # Authorities arrest 118 people in airline ticket fraud sting

    Credit card companies and airlines teamed up to help find fraudsters.

    by Megan Geuss - Nov 28, 9:50 pm UTC

    20

## Recent Feature Stories

- ## Feature Story (5 pages)

  # Learning the science behind silencers on the range with SilencerCo

  Hollywood gets it consistently wrong—in the real world, they're merely less loud.

  by Lee Hutchinson - Dec 2, 4:00 pm UTC

  279

- ## Feature Story (4 pages)

  # Firefly Space Systems charges full-speed toward low Earth orbit

  True believers build rockets, engines, and space dreams on the Texas prairie.

  by Lee Hutchinson - Nov 30, 6:00 pm UTC

  126

## Watch Ars Video

# Shooting silencers with SilencerCo

Listen to the tamed sounds of the gun range, thanks to SilencerCo's suppressors.

- ## Stay in the know with

- ## Feature Story (3 pages)

  # iWork ’14 review: Still waiting for that great leap forward [Updated]

  No backward compatibility, but it's hard to argue with free.

  by Iljitsch van Beijnum - Nov 28, 12:00 am UTC

  120

- ## Feature Story (4 pages)

  # How an eBay bookseller defeated a publishing giant at the Supreme Court

  Supap Kirtsaeng is a rebel without a pause, as the copyright fight isn't over yet.

  by Doug Kari Nov 25, 4:00 pm UTC

  188

- ## Ars Feature Story Archive →

Read more stories